import Vue from 'vue';
import vuexAlong from './vuex-along';
import router from './router';
import store from './store';
const EVENT_KEYS = Object.freeze({
  beforeEach: true,
  beforeResolve: true,
  afterEach: true,
  onReady: true,
  onError: true
});
export default {
  start(moduleConfig) {
    const application = moduleConfig.getApplication();
    vuexAlong.setKey(`${application.name}-${application.version}`);
    let configs = moduleConfig.getExtension('vuex.module');

    for (let key in configs) {
      store.registerModule(key, configs[key]);
    }

    configs = moduleConfig.getExtension('vue.plugin');

    for (let key in configs) {
      Vue.use(configs[key]);
    }

    const options = [];
    configs = moduleConfig.getExtension('vue.options');

    for (let key in configs) {
      options.push(configs[key]);
    }

    configs = moduleConfig.getExtension('vue.router');

    for (let key in configs) {
      if (key === '/') {
        router.addRoutes(configs[key]);
      }
    }

    configs = moduleConfig.getExtension('vue.router.event');

    for (let key in configs) {
      const config = configs[key];

      for (let event in config) {
        if (EVENT_KEYS[event]) {
          router[event](config[event]);
        }
      }
    }

    const app = moduleConfig.getExtension('vue.app');
    const vueOptions = {
      router,
      store,
      mixins: options,
      render: h => h(app.component)
    };
    new Vue(vueOptions).$mount(app.el);
  }

};